@@ -10,7 +10,14 @@ def lambda_prepare_node(region, account_id, cytoscape_node_data):
         script_dir, 'data/lambda-list-functions-'+region+'.json')
     with open(file_path_read, 'r') as openfile:
         lambda_object = json.load(openfile)
+        openfile.close()
         for item in lambda_object['Functions']:
+            file_path_read_tag=os.path.join(script_dir,
+            'data/lambda-list-tags/lambda-list-tags-'+item["FunctionName"]+'.json')
+            with open(file_path_read_tag,'r') as openfile_tag:
+                lambda_tag_object=json.load(openfile_tag)
+                openfile_tag.close()
+            lambda_tag=lambda_tag_object['Tags']
             cytoscape_node_data.append({
                 "data": {
                     "type": "Lambda",
@@ -25,8 +32,8 @@ def lambda_prepare_node(region, account_id, cytoscape_node_data):
                     "name": item['FunctionName'],
                     "description": item['Description'],
                     "role": item['Role'],
-                    "codesize": item['CodeSize']
+                    "codesize": item['CodeSize'],
+                    "tag": lambda_tag,
+                    "cost_for_month": 0.03
                 }
             })
-
-        openfile.close()
