@@ -3,8 +3,9 @@ import json
 import os
 
 
-def s3_get_bucket_policy_status(region):
-    client = boto3.client('s3', region_name=region)
+def s3_get_bucket_policy_status(region,AWS_ACCESS_KEY,AWS_SECRET_KEY):
+    client = boto3.client('s3', region_name=region,
+    aws_access_key_id=AWS_ACCESS_KEY, aws_secret_access_key=AWS_SECRET_KEY)
     try:
         script_dir = os.path.dirname('.')
         file_path = os.path.join(
